/*MAIN CLEANING FILE
-- Cleans and prepares wave 2 of CRAM + merges all Wave 2 files together along with deflating
-- Note: to use the file with CRAM Wave 1, will need to merge this to the w5_nc file after running the cleaning file for that.
-- Defines earnings, employment 
*/


if c(username)=="ronak" {
	clear all
	global cram_w2  "C:\Users\ronak\Desktop\cram_w2"  // "C:\Users\ronak\Dropbox (Harvard University)\CRAM paper\"
	global trash "C:\Users\ronak\Desktop\cram_w2\"
	global cram "C:\Users\ronak\Dropbox\CRAM paper"
}
if c(username)=="ihsaa" {
	clear all
	global cram_w2  "C:\Users\ihsaa\Dropbox\CRAM paper\Wave 2"  // "C:\Users\ronak\Dropbox (Harvard University)\CRAM paper\"
	global trash "C:\Users\ihsaa\Documents\Data"
	global cram "C:\Users\ihsaa\Dropbox\CRAM paper"
}
if c(username)=="joshb" {
	clear all
	global cram_w2  "C:\Users\joshb\Dropbox\projects\CRAM paper\Wave 2"  
	global trash "C:\Users\joshb\Desktop\inbox"
	global cram "C:\Users\joshb\Dropbox\projects\CRAM paper"
}


********************************************************************
*LINK FILES
********************************************************************


use "${cram_w2}\Data\NIDS-CRAM_Wave2_Anon_V1.1.0.dta", clear
merge 1:1 pid using "${cram_w2}\Data\Link_File_NIDS-CRAM_Wave2_Anon_V1.1.0.dta", // assert(match) - 22 in using only (dropping these)
drop if _merge==2 //These are all deceased
drop _merge
merge 1:1 pid using "${cram_w2}\Data\derived_NIDS-CRAM_Wave2_Anon_V1.1.0.dta", // assert(match) - 1395 only in master (keeping these)
*non matched all didn't answer Qs (mostly not contacted)
drop if _merge==2
drop _merge

*adding deflator
scalar base=115.2 												//Set scalar to base month, currently Feb 2020
cap drop w2_nc_deflator
gen w2_nc_deflator=.
replace w2_nc_deflator=base/116.4       // July 2020


lab var w2_nc_deflator "NIDS-CRAM W2 deflator"

rename w2_nc_* w7_*
g fwgt= round(w7_pweight)
numlabel, add

*Keep em days neg
g w7_emdaysneg_jun= w7_emdays_jun 


//Get rid of refusal and don't know
//NB: w2_nc_emdays_june -7 is "I was on leave" and 232 cases are coded as missing (as we did last time) - just flagging
foreach var in w7_eminc_june w7_eminc_june_brac w7_emwkinc_june w7_emwkinc_june_brac w7_emdayinc_june w7_em2wksinc_june w7_em2wksinc_june_brac w7_emsinc_june w7_emsinc_june_brac w7_emdays_june {
	recode `var' (-9/-1=.)
}

// fix for the nids-cram derived employment variable (because we're still using v1.0.0 just to avoid extra mess). we don't use this variable, but just in case...
replace w7_empl_stat=0 if w7_em_june==3
	

********************************************************************************
*** Earnings
********************************************************************************

* bracket vars check for updated data:
foreach var in w7_eminc_june_brac w7_emwkinc_june_brac w7_em2wksinc_june_brac w7_emsinc_june_brac    {
	assert inlist(`var', 1,2,3,4,5,6,.)
}

//June EARNINGS 
	*Also need to convert all figures to a monthly figure
	
// Monthly earnings (1177 non missing)
	local mbrac1 ERROR
	local mbrac2 1,3000
	local mbrac3 3001,6000
	local mbrac4 6001,12000
	local mbrac5 12001,24000
	local mbrac6 ERROR
	local mbracend 24000
	
	g w7_eminc_jun_imp= w7_eminc_june
	replace w7_eminc_jun_imp = 0 if w7_eminc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_eminc_june if inrange(w7_eminc_june, `mbrac`i''), d
		replace w7_eminc_jun_imp = r(p50) if w7_eminc_june_brac == `i'
	}
	replace w7_eminc_jun_imp = 2*`mbracend' if w7_eminc_june_brac ==6
	
	
// Weekly earnings (143 non missing)
	local wbrac1 ERROR
	local wbrac2 1,700
	local wbrac3 701,1400
	local wbrac4 1401,2800
	local wbrac5 2801,5500
	local wbrac6 ERROR
	local wbracend 5500

	g w7_emwkinc_jun_imp= w7_emwkinc_june
	replace w7_emwkinc_jun_imp = 0 if w7_emwkinc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_emwkinc_june if inrange(w7_emwkinc_june, `wbrac`i''), d
		replace w7_emwkinc_jun_imp = r(p50) if w7_emwkinc_june_brac == `i'
	}
	replace w7_emwkinc_jun_imp = 2*`wbracend' if w7_emwkinc_june_brac ==6
	
	
// Fortnightly earnings (87 non missing)
	local fbrac1 ERROR
	local fbrac2 1,1400
	local fbrac3 1401,2800
	local fbrac4 2801,5500
	local fbrac5 5501,11000
	local fbrac6 ERROR
	local fbracend 11000
	
	g w7_em2wksinc_jun_imp= w7_em2wksinc_june
	replace w7_em2wksinc_jun_imp = 0 if w7_em2wksinc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_em2wksinc_june if inrange(w7_em2wksinc_june, `fbrac`i''), d
		replace w7_em2wksinc_jun_imp = r(p50) if w7_em2wksinc_june_brac == `i'
	}
	replace w7_em2wksinc_jun_imp = 2*`fbracend' if w7_em2wksinc_june_brac ==6
	

//Convert all earnings to monthly 
	* Multipling up to monthly totals. Just check whether the frequency var works as a flag for this replacement:
	assert mi(w7_eminc_june) if inlist(w7_empay_freq,1,2,3)	
	assert w7_empay_freq == 1 if !mi(w7_emdayinc_june)
	assert w7_empay_freq == 2 if !mi(w7_emwkinc_june)
	assert w7_empay_freq == 3 if !mi(w7_em2wksinc_june)	// all good
	
	* JB: just to confirm that we shouldn't be using embusdays_apr for daily wage, confirm that those who report self-emp or "run a business" do not report daily earnings:
	assert mi(w7_emdayinc_june) if inlist(w7_emtyp, 3,4)
	
	gen temp_day_monthly = w7_emdayinc_june*w7_emdays_june*4.33 if w7_emdays_june >= 0 
		// RJ none report zero days so don't have the problem we had in w1 of some workers reporting daily earnings but no days
	gen temp_wk_monthly = w7_emwkinc_jun_imp*4.33
	gen temp_2wks_monthly = w7_em2wksinc_jun_imp*2.17
		
	* Sub in imputed daily, weekly and 2-weekly earnings
	replace w7_eminc_jun_imp = temp_day_monthly if mi(w7_eminc_jun_imp)
	replace w7_eminc_jun_imp = temp_wk_monthly if mi(w7_eminc_jun_imp)
	replace w7_eminc_jun_imp = temp_2wks_monthly if mi(w7_eminc_jun_imp)
	

// some JB checks (RJ: retained from earlier wave - updated code for June to check the earnings density)
	// check
	/*
	su temp_day_monthly temp_wk_monthly temp_2wks_monthly [aw = w7_wgt], d
	local klist
	foreach var in w7_eminc_jun temp_day_monthly temp_wk_monthly temp_2wks_monthly {
		cap drop ln_`var'
		gen ln_`var' = ln(`var')
		
		
		* comment out version below you don't want
		local klist `klist' (kdensity ln_`var' ) 
		// local klist `klist' (kdensity ln_`var' [aw = w6_wgt]) 
	}
	twoway `klist'
		
	
	* notable: you can't get rid of the february hump by excluding daily, weekly, fortnightly earnings [!inlist(w7_empay_freq, 1,2,3)]
	* instead, you can only get rid of it by *only including monthly earnings* (w7_empay_freq==4). This suggests the hump is *not* about reporting frequency, but is instead about the people who report wages in February, but no longer report earnings in April. could this just be about super polarised SA labour market and disproportionate impact of covid?
	cap drop test_monwage
	gen test_monwage = w6_eminc_apr
		replace test_monwage = temp_day_monthly if mi(test_monwage)
		replace test_monwage = temp_wk_monthly if mi(test_monwage)
		replace test_monwage = temp_2wks_monthly if mi(test_monwage)
	cap drop ln_test_monwage
	gen ln_test_monwage = ln(test_monwage)
	cap drop ln_w7_eminc_june
	gen ln_w7_eminc_jun_imp = ln(w7_eminc_feb_imp)	
	cap drop ln_w7_apr_inc
	gen ln_w7_apr_inc = ln_test_monwage 
	twoway (kdensity ln_w7_apr_inc [aw = w7_wgt]) (kdensity ln_w7_eminc_feb [aw = w7_wgt]) // if !mi(w7_empay_freq)
	cap drop test_monwage  ln_test_monwage ln_w7_eminc_feb ln_w7_apr_inc
*/

	drop temp_day_monthly temp_wk_monthly temp_2wks_monthly

	
//June profits (267 non-missing)
	g w7_emsinc_jun_imp= w7_emsinc_june 
	replace w7_emsinc_jun_imp = 0 if w7_emsinc_june_brac ==1
	
	sum w7_emsinc_june if w7_emsinc_june >0 & w7_emsinc_june <3000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==2
	sum w7_emsinc_june if w7_emsinc_june >=3000 & w7_emsinc_june<=6000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==3
	sum w7_emsinc_june if w7_emsinc_june >6000 & w7_emsinc_june<=12000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==4
	sum w7_emsinc_june if w7_emsinc_june>12000 & w7_emsinc_june<=24000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==5	
	replace w7_emsinc_jun_imp = 2*24000 if w7_emsinc_june_brac ==6
	
	
//June totwage
	egen w7_totwage_jun = rsum(w7_emsinc_jun_imp w7_eminc_jun_imp), missing
	replace w7_totwage_jun =. if w7_totwage_jun >100000 // Note: Find a better way of trimming outliers. 3 set to missing.
	


********************************************************************************
*** Employment status
********************************************************************************

//Clean up days var
g w7_emdays_jun_imp= w7_emdays_june
//JB: just confirm that it only exists for self-employed and business owners
assert mi( w7_embusdays_june) if !inlist(w7_emtyp,3,4)

replace w7_emdays_jun_imp= w7_embusdays_june if w7_emdays_jun_imp==. & w7_embusdays_june>=0

//JB edited Label
// lab def w7_empcat 1 "Emp,days>0,wage>0" 2 "Emp,days=0,wage>0" 3 "Emp,days=0,wage=0" 4 "Unemp,days=0,wage=0", modify

lab def w7_empcat 1 `""Working": days>0"' 2 `""Paid leave": days=0,wage>0"' 3 `""Unpaid leave": emp/emreturn,days=0,wage=0"' 4 `""Not employed": noemp,days=0,wage=0"', modify

//Doing the same as for feb and april (prioritize comparibility)
foreach mo in jun {
	
	*JB: some checks before we get going
	assert w7_emdays_`mo'_imp >= 0
	assert w7_totwage_`mo' >= 0
	
	cap drop w7_empcat_`mo'
	g w7_empcat_`mo'= .
	
	*1 - days>0
	replace w7_empcat_`mo'= 1 if (w7_emdays_`mo'_imp>0 & w7_emdays_`mo'_imp!=.)
	
	*2 - days==0, wage>0
	replace w7_empcat_`mo'= 2 if (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'>0 & w7_totwage_`mo'!=.)
	
	*3 - emp, days==0, wage==0 ;; also 49 obs "no i'm emp", wage==0, hr==0
	replace w7_empcat_`mo'= 3 if (w7_em_`mo'==1 | w7_emany_`mo'==1 | w7_ems_`mo'==1) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.)  ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	replace w7_empcat_`mo'= 3 if (w7_em_`mo' ==2 & w7_emany_`mo'==2 & w7_ems_`mo' == 2) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	*4 - unemp, wage==0, days==0
	replace w7_empcat_`mo'= 4 if (w7_em_`mo'==2 & w7_emany_`mo'==2 & w7_ems_`mo'==3) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	lab val w7_empcat_`mo' w7_empcat
}


*Specific adjustment: Those who earn daily wage in april and say emp but no days. Assign cat 2. (5 changes)
replace w7_empcat_jun= 2 if (w7_em_june==1 | w7_emany_june==1 | w7_ems_june==1) & (w7_emdays_june==.) & (w7_emdayinc_june !=.)

*Specific adjustment: Set emp==3 if return job + reason=lockdown broadly (no wage, no hrs) 
* restrict changes to when w7_empcat_jun==4 or w7_empcat_jun==., and expanding w7_emabs_june reasons (excludes "studying" and "poor health", "retrenched" and "maternity leave") (92 real changes)
replace w7_empcat_jun= 3 if inlist(w7_emabs_june,1,2,4,5,6) & w7_emreturn==1 & inlist(w7_empcat_jun, 4,.)

* JB change: set June pensioners to category 4 as NEA. means we have empcat for almost everyone, also logically consistent
*assert mi(w7_empcat_jun) if  w6_em_feb == 3 //keeping to check in the merged file
replace w7_empcat_jun = 4 if w7_em_june == 3 //(533 changes)
*only 44 missing status AND successfully interviewed (w7_outcome)

*Specific adjustment: emp missing or not emp, but answer paid leave
	replace  w7_empcat_jun= 3 if !(w7_em_jun==1 | w7_emany_jun==1 | w7_ems_jun==1) & (w7_empcat_jun==4 | w7_empcat_jun==.) & w7_emdaysneg_jun==-7




/*Investigate missings
*44 missing, none have wage
tab w7_emdaysneg_jun if w7_empcat_jun==. & w7_outcome==1, mi
sum w7_totwage_jun if w7_empcat_jun==. & w7_outcome==1

*15 have idk for all three
count if w7_empcat_jun==. & w7_outcome==1 & inlist(w7_em_jun,-9,-8) & inlist(w7_emany_jun,-9,-8) & inlist(w7_ems_jun,-9,-8) & w7_totwage_jun==.

*15 refused all three, 10 refused ems + No any job  + ref/no any work
table w7_em_jun w7_emany_jun if w7_empcat_jun==. & w7_outcome==1, c(freq) by(w7_ems_jun)

*/



/*IB NOTES (RJ: leaving these from the earlier waves - updated the code)
-- Sets unemp w/ pos wages as emp w/ pos wages
-- Cat 3 <-- "no I'm employed" + no hrs + no wage
-- Exclude retired ==> set to missing
-- hours is only asked if employed

Notes on consistentcy derived vs our emplstat var
-- recover w7_empl_stat  through comb of vars:
count if (w7_em_jun==1 | w7_emany_jun==1 | w7_ems_jun==1) | w7_emreturn==1 | w7_emdays_june!=. | w7_empay_freq!=. | w7_embusdays_jun!=.

tab w7_empl_stat w7_empcat_jun if nids_sample!=., mi
-- if employed in w7_empcat_jun, then emp in w7_empl_stat 
-- if unemp in w7_empcat_jun, x/y NEA or unemp (consistent), x refused (fine),x/y employed (Bad)
		tab w7_empcat_jun w7_emreturn if w7_empl_stat==3
		*All x unemp have job to return to (not lockdown related)
-- if missing in w7_empcat_jun (x/y), x emp (bad) and x refused (okay)
		*This is fine :)
*/

// JB NOTES (RJ: leaving these from the earlier waves - updated the code)
**** compare our emp category to derived empl_stat
// tab w7_empcat_jun w7_empl_stat  if w7_outcome==1, mi
* all of our cat1, cat2, cat3 come from empl_stat employed
* x/y of our "not employed" are employed in empl_stat
*---> they're all emreturn == 1 with various reasons. vast majority not lockdown related, seem inconsistent with emreturn==1
* we have x missing in empcat. x have no empstatus, while x,x,x are NEA, unemp, emp respectively.



********************************************************************************
*** HH income
********************************************************************************



*everyone is asked the hhincome question... 
// assert !mi(w7_hhinc) if w7_outcome == 1		// JB: v1 edit to comment this out. 

recode w7_hhinc (-9/-1 = .)
rename w7_hhinc w7_hhincome

	local fbrac1 1,1500
	local fbrac2 1501,3000
	local fbrac3 3001,5000
	local fbracend 5000
	
	g w7_hhincome_imp= w7_hhincome
	forval i = 1/3 {
		su w7_hhincome if inrange(w7_hhincome, `fbrac`i''), d
		replace w7_hhincome_imp = r(p50) if w7_hhinc_brac == `i'
	}
	replace w7_hhincome_imp = 2*`fbracend' if w7_hhinc_brac ==4
	

/*
cap drop mi_hhinc
gen mi_hhinc = (mi(w7_hhincome_imp) & w7_outcome == 1)
tab mi_hhinc if w7_outcome == 1, m
tab mi_hhinc if w7_outcome == 1 [fw = fwgt], m
cap drop mi_hhinc
*/
	



********************************************************************************
*** Deflating (RJ: still needs to be done post merging)
********************************************************************************

*** NIDS-CRAM. some JB edits 
*According to StatsSA, no inflation over feb to march [you mean April? JB]...
foreach var in w7_hhincome_imp w7_hhincome w7_totwage_jun w7_eminc_june w7_eminc_jun_imp w7_emsinc_june w7_emsinc_jun_imp w7_emwkinc_june /*w7_emwkinc_june_brac*/ w7_em2wksinc_june /*w7_em2wksinc_june_brac*/ w7_emdayinc_june {
	replace `var' = `var'*w7_deflator
}



*===============================================================================
***	Cleaning and harmonising variables between NIDS and NIDS-CRAM W1 and W2 (RJ: still needs to be done post merging)
*===============================================================================

*** Age
	rename w7_best_age_yrs w7_age
	recode w7_age (-9/-1=.)

*** Gender
	ren w7_best_gen w7_gender
	
*** Race 
	rename w7_best_race w7_race
	recode w7_race  (-8/-1=.)
	
*** Area
	recode w7_geo2011 (-8/-1=.)
	assert w7_geo2011 >= 0	
	// JBedit2
	drop w7_area
	clonevar w7_area = w7_geo2011  
	
*** Province
	recode w7_prov2011 (-9/-1=.) (10=.)
	assert w7_prov2011 >= 0
	drop w7_prov
	rename w7_prov2011 w7_prov
	
*** Household composition	
	rename w7_nopres w7_hhsizer 
	replace w7_hhsizer = . if w7_hhsizer ==0 // no observatoins who report zero hhsize.
	rename w7_nou7res w7_tot_child_7
	rename w7_nou18res w7_tot_child
	rename w7_no60res w7_tot_elder
	
	recode w7_hhsizer w7_tot_child w7_tot_child_7 w7_tot_elder w7_nocld w7_nopres_conf (-9/-1=.)
	
	gen w7_tot_adult = w7_hhsizer-(w7_tot_elder+w7_tot_child)
	gen w7_childrenelders = w7_tot_elder+w7_tot_child
			
	*assert w7_tot_adult >=0 //29 failures 
	*assert w7_childrenelders <= w7_hhsizer if !mi(w7_childrenelders) //29 failures - flagging
	
	*Replace with confirmed number if conflicting
	egen tempsize= rowtotal(w7_tot_child w7_tot_elder w7_nocld)
	*count if tempsize!=w7_hhsizer & w7_outcome==1
	replace w7_hhsizer= w7_nopres_conf if tempsize!=w7_hhsizer & w7_outcome==1 & w7_nopres_conf!=.
	drop tempsize

/*
-- Half don't match up (2755), mostly confirmed as errors in the
	subqs. 375 replacements.
-- Many of the differences come from missing 18-60 number of adults
*/
	
		
*** Education 
assert w7_edschgrd != 20

gen w7_educ_bins = .
replace w7_educ_bins = 1 if inrange(w7_edschgrd, 0, 7) |  w7_edschgrd==19
replace w7_educ_bins = 2 if inrange(w7_edschgrd, 8, 11) | inlist( w7_edschgrd, 13,14,16,17)
replace w7_educ_bins = 3 if inlist(w7_edschgrd, 12,15,18)
replace w7_educ_bins = 4 if w7_edter== 1 & inlist(w7_edschgrd, 12,15,18)
	
la de educ_bins 1 "Up to Primary" 2 "Up to Secondary" 3 "Matric" 4 "Tertiary", modify
lab val w7_educ_bins educ_bins

***Occupation 
	
	* Wave 7*	
	recode w7_emwrk_isco_c w7_emswrk_isco_c w7_unemwrk_isco_c (-9/-1 = .)
	gen w7_occu = .
	
	//JB simplifying code and make structure of industry codes clearer. without these asserts one has to check the skip-pattern anyway to make sure the code makes sense.
	//assert mi(w7_emswrk_isco_c) & mi(w7_unemwrk_isco_c) if !mi(w7_emwrk_isco_c) 
	//RJ: note this fails for 1 observation where w7_emswrk_isco_c is arts and crafts (for now ignoring this)
	replace w7_occu = w7_emwrk_isco_c 
	
	//assert mi(w7_emwrk_isco_c) & mi(w7_unemwrk_isco_c) if !mi(w7_emswrk_isco_c)
	//RJ: note this fails for 1 observation where w7_emswrk_isco_c is arts and crafts (for now ignoring this)
	replace w7_occu = w7_emswrk_isco_c if mi(w7_occu)
	
	assert mi(w7_emwrk_isco_c) & mi(w7_emswrk_isco_c) if !mi(w7_unemwrk_isco_c)
	replace w7_occu = w7_unemwrk_isco_c if mi(w7_occu)
    
	label val w7_occu w2_nc_occ_code
		
*** Type of work
	recode w7_emtyp (-9/-1=.)	

/*RJ: to be added after merging the w7 file with the w1 file - code is updated
//job loss
// gen job_loss2 = 0 if w7_empcat_feb==1
// replace job_loss2 = 1 if w7_empcat_apr!=1 & w7_empcat_apr!=. & w7_empcat_feb==1

gen jobloss_234 = 0 if w7_empcat_feb==1
replace jobloss_234 = 1 if inlist(w7_empcat_jun, 2,3,4) & w7_empcat_apr==1
lab var jobloss_234 "Job loss: switched from empcat 1 to empcat 2,3 or 4"

gen jobloss_34 = 0 if w7_empcat_feb==1
replace jobloss_34 = 1 if inlist(w7_empcat_jun, 3,4) & w7_empcat_apr==1
lab var jobloss_34 "Job loss: switched from empcat 1 to empcat 3 or 4"
*/	




******************************************************************
*FURTHER CLEANING (RJ: only keeping those vars which we use in analysis)
******************************************************************
	
* Careful to make these changes AFTER employment variables defined
	recode w7_emhrs_june (-9/-1 = .) (19/24 = .)  // Recoding implausibly large numbers to missing
	recode w7_emdays_june (-9/-1 = .) (8/max = .)  // Recoding implausibly large numbers to missing
	gen w7_emhrswk_june = w7_emhrs_june*w7_emdays_june
	lab var w7_emhrswk_june "Average work week (Hours)"

/*RJ: to be added after merging the w7 file with the w1 file - code is updated
*** Hours reduction 
	gen wkhrs_reduc = .
	replace wkhrs_reduc = w7_emhrswk_apr - w7_emhrswk_june if w7_emhrswk_apr !=. & w7_emhrswk_june !=.
	replace wkhrs_reduc = w7_emhrswk_apr if w7_emhrswk_apr !=. & w7_emhrswk_june ==.
	replace wkhrs_reduc = -w7_emhrswk_june if w7_emhrswk_apr ==. & w7_emhrswk_june !=.		// JB addition

RJ: From earlier wave (keeping to check again) - JB: why so few obs with this hours reduc variable? its because of NEA people. actually coverage pretty good for first 3 categories of w7_empcat_june (though not perfect)
/*
cap drop hrsreduc_nm
gen hrsreduc_nm = !mi(wkhrs_reduc)
tab w7_empcat_june, sum(hrsreduc_nm)
cap drop hrsreduc_nm
*/
*/


*** July/Aug COVID grant application (JB3)
	recode w7_incvgrt (-8/-3 =.)

***	Written contract / formal employment
	recode w7_emcontr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(w7_formal)	
	lab var w7_formal "Written employment agreement"
	
***Payment frequency 
	recode w7_empay_freq (-8=.)	
	
*** TERS/UIF
	*Note: The NIDS variable related to whether UIF is deducted from one's salary. This is a different concept to the CRAM question, which asks about relief through UIF.
	recode w7_eminc_ters (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=3 "Waiting"), gen(w7_tersuif)
	assert w7_tersuif >= 0
	//130,000 waiting, 2m yes.
	//RJ: added for this wave- w7_emsteers_june - asked to businesses 
	recode w7_emsteers_june (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=3 "Waiting") (4=4 "Ineligible") (5=5 "Don't know how to") (6=6 "Other support")  , gen(w7_emsters_jun)
	assert w7_emsters_jun >= 0

	*It seems 1.5/1.9 mill TERs recip working, none unemp (good)
	*Partial or delayed compensation is important
	// tab w7_eminc_ters w7_empcat_jun if w7_outcome == 1 & inlist(w7_empcat_jun,1) , m
	
	recode w7_unemincuifany_june (1=1 "Yes") (2=0 "No") (-9/-8 = .), gen(w7_rwtbenuif_yn)
	assert w7_rwtbenuif_yn >= 0
	lab var w7_rwtbenuif_yn "UIF reduced work-time benefit, juneil"

*** CSG
	 rename w7_hhincchld w7_csg_number 
	 recode w7_csg_number (-9/-3 = .) 
	 assert w7_csg_number >=0 & w7_csg_number < 20 if !mi(w7_csg_number)
	 replace w7_csg_number = 1 if w7_csg_number ==. & w7_incchld == 1  
	 
***	OAPs in household
	rename w7_hhincgovpen w7_oap_number
	recode w7_oap_number (-9/-3 = .)  
	replace w7_oap_number = 1 if w7_oap_number ==. & w7_incgovpen== 1 
	 

*** SRD in household	// some errors here I'm fixing
	rename w7_hhinccv_june  w7_srd_number
	replace w7_srd_number = 1 if w7_srd_number == -7	// JB2
	recode w7_srd_number (-9/-3 = .)  
	//replace w7_srd_number = 1 if w7_srd_number ==. & w7_incvgrt== 1 		// JB3 taken this out (only want June receipt in here)
	  	
***	Personal grant reciept - CRAM
	
	 recode w7_incgov_june (-9/-8=.) (1=1) (2=0)
	 label define w7_incgov 0 "No" 1 "Yes"
	 label val w7_incgov_june w7_incgov
	 recode w7_incgovtyp1 (-9/-8=.)
	 
*RJ - adapted code acc to questionnaire changes 	 
tab w7_incgovtyp1, gen(indgrnt)
 
*Numbering thrown off bc of skips. Labels kept and checked.
rename indgrnt1 w7_ind_incchld 
rename indgrnt2 w7_ind_incgovpen  
rename indgrnt3 w7_ind_incdis
rename indgrnt4 w7_ind_incfos 
rename indgrnt5 w7_ind_inccare  
rename indgrnt6 w7_ind_incwar	
*rename indgrnt6 w7_ind_incsrd 
rename indgrnt7 w7_ind_inccovid  
rename indgrnt9 w7_ind_incaid
rename indgrnt10 w7_ind_incnsfas 

drop indgrnt8
	 
forval i = 2/4 {	 
	replace w7_ind_incchld = 1  if w7_incgovtyp`i' == 1
	replace w7_ind_incgovpen = 1  if w7_incgovtyp`i' == 2
	replace w7_ind_incdis = 1 if w7_incgovtyp`i' == 3
	replace w7_ind_incfos = 1  if w7_incgovtyp`i' == 4
	replace w7_ind_inccare = 1  if w7_incgovtyp`i' == 5
	replace w7_ind_incwar = 1	 if w7_incgovtyp`i' == 7
	replace w7_ind_inccovid = 1  if w7_incgovtyp`i' == 8
	replace w7_ind_incaid = 1 if w7_incgovtyp`i' == 10
	replace w7_ind_incnsfas = 1  if w7_incgovtyp`i' == 11
}


//Replace oap, csg and srd if individual receives but hh doesn't (JB2 we kind of already did this for SRD with incvrgt above)
replace w7_csg_number = 1 if (w7_csg_number==. | w7_csg_number==0) & w7_ind_incchld==1  
replace w7_oap_number = 1 if (w7_oap_number ==. | w7_oap_number==0) & w7_ind_incgovpen== 1 
replace w7_srd_number = 1 if (w7_srd_number ==. | w7_srd_number==0) & w7_ind_inccovid== 1 


/* RJ: leaving this for checking after merging with w1
* JB: checking grants
tabstat w7_ind_incchld w7_ind_incgovpen w7_ind_incdis w7_ind_inccovid w7_ind_incnsfas [fw=fwgt], s(sum)

cap drop w7_fwgt w6_fwgt w5_fwgt
gen w7_fwgt = fwgt
gen w6_fwgt = round(w6_wgt)
gen w5_fwgt = round(w5_wgt)

foreach wv in w5 w7 {
	tab `wv'_ind_incdis [fw=`wv'_fwgt]
	tab `wv'_ind_incchld  [fw=`wv'_fwgt]
	tab `wv'_ind_incfos  [fw=`wv'_fwgt]
	tab `wv'_ind_inccare  [fw=`wv'_fwgt]
	tab `wv'_ind_incgovpen  [fw=`wv'_fwgt]
	tab `wv'_ind_incwar [fw=`wv'_fwgt]
	***
}

tabstat w5_csg_number  w5_oap_number [fw=w5_fwgt] if w5_age>17, s(sum)
tabstat w6_csg_number  w6_oap_number [fw=w6_fwgt], s(sum)
tabstat w7_csg_number  w7_oap_number [fw=w7_fwgt], s(sum)
cap drop w7_fwgt w6_fwgt w5_fwgt
*/

*** Food 
	recode w7_hhfdyn (-9/-1=.) (1=1) (2=0)  

**GRANT coverage (added SRD grant)
*** Create household grant receipt ***
gen w7_hhincgov = .
replace w7_hhincgov = 1 if w7_csg_number > 0 & !mi(w7_csg_number)
replace w7_hhincgov = 1 if w7_oap_number > 0 & !mi(w7_oap_number)
replace w7_hhincgov = 1 if w7_srd_number > 0 & !mi(w7_srd_number)
replace w7_hhincgov = 1 if w7_incgov_june == 1
replace w7_hhincgov = 0 if w7_incgov_june == 0 & w7_csg_number == 0 & w7_oap_number == 0 & w7_srd_number==0
// 1560 missing obs - RJ: this is very high and coming mostly from missings on ind grant  w7_incgov_june
//IB: only 182 missing if we exclude non-response. So all good. 
//JB: these 182 come from  missing csg, oap and srd (often overlapping):
	* inspect w7_csg_number w7_oap_number w7_srd_number w7_incgov_june if w7_outcome==1 & w7_hhincgov==.
lab var w7_hhincgov "Grant receipt in household"



//Updated for SRD vs other grants
g w7_hhsrd= 0 if w7_srd_number==0 
replace w7_hhsrd=1 if (w7_srd_number > 0 & !mi(w7_srd_number))



* JB2: not sure about this given complex nature of SRD variable... does w7_ind_inccovid cut it? leaving for now. not sure it's right. what about disab grant person who also receives SRD? suppose technically not possible, and such few numbers too actually. whatever
g w7_hhothergrant= 0 if w7_hhincgov!=.
replace w7_hhothergrant= 1 if (w7_oap_number > 0 & !mi(w7_oap_number)) | (w7_csg_number > 0 & !mi(w7_csg_number)) | (w7_incgov_june==1 & w7_ind_inccovid!=1)

gen cover_grnt_unemp = .
replace cover_grnt_unemp = 1 if w7_hhsrd == 0 & w7_hhothergrant == 0
replace cover_grnt_unemp = 2 if w7_hhsrd == 1 & w7_hhothergrant == 0
replace cover_grnt_unemp = 3 if w7_hhsrd == 0 & w7_hhothergrant == 1
replace cover_grnt_unemp = 4 if w7_hhsrd == 1 & w7_hhothergrant == 1

label define cover_grnt_unemp 1 "No cover" 2 "HH SRD only" 3 "HH other Grant only" 4 "Both", modify
lab val cover_grnt_unemp  cover_grnt_unemp 
lab var cover_grnt_unemp "Coverage of grants"

*Do uif version
gen cover_uif_unemp = .
replace cover_uif_unemp = 1 if w7_rwtbenuif_yn!=1 & w7_hhincgov == 0
replace cover_uif_unemp = 2 if w7_rwtbenuif_yn== 1 & w7_hhincgov == 0
replace cover_uif_unemp = 3 if w7_rwtbenuif_yn!= 1 & w7_hhincgov == 1
replace cover_uif_unemp = 4 if w7_rwtbenuif_yn== 1 & w7_hhincgov == 1


label define cover_uif_unemp 1 "No cover" 2 "UIF only" 3 "HH Grant only" 4 "Both", modify
lab val cover_uif_unemp  cover_uif_unemp 
lab var cover_uif_unemp "Coverage of grants"


*Do SRD version
gen cover_srd_unemp = .
replace cover_srd_unemp = 1 if w7_hhsrd == 0 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_srd_unemp = 2 if w7_hhsrd == 1 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_srd_unemp = 3 if w7_hhsrd == 0 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)
replace cover_srd_unemp = 4 if w7_hhsrd == 1 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)


label define cover_srd_unemp 1 "No cover" 2 "HH SRD only" 3 "HH other protection only" 4 "Both", modify
lab val cover_srd_unemp  cover_srd_unemp 
lab var cover_srd_unemp "Coverage of grants"




*Do SRD version (July-Aug)
g srd_jul= (w7_incvgrt == 1)

gen cover_indsrd_unemp = .
replace cover_indsrd_unemp = 1 if srd_jul == 0 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_indsrd_unemp = 2 if srd_jul == 1 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_indsrd_unemp = 3 if srd_jul == 0 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)
replace cover_indsrd_unemp = 4 if srd_jul == 1 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)

label define cover_indsrd_unemp 1 "No cover" 2 "Indiv SRD only" 3 "HH other protection only" 4 "Both", modify
lab val cover_indsrd_unemp  cover_indsrd_unemp 



*TERS
gen cover_grnt_ters = .
replace cover_grnt_ters = 1 if w7_tersuif == 0 & w7_incgov_june == 0
replace cover_grnt_ters = 2 if w7_tersuif == 1 & w7_incgov_june == 0
replace cover_grnt_ters = 3 if w7_tersuif == 0 & w7_incgov_june == 1
replace cover_grnt_ters = 4 if w7_tersuif == 1 & w7_incgov_june == 1

label define cover_grnt_ters 1 "No cover" 2 "TERS only" 3 "Ind grant only" 4 "Both", replace
lab val cover_grnt_ters cover_grnt_ters
lab var cover_grnt_ters "Coverage of grants and TERS"




***** Income losses
* Change in main source of income //NB: No 'any source income loss'
recode w7_hhincchng (-9/-1=.) 
recode w7_hhincchng (2=1 "Decreased") (1/3=0 "No"), gen(w7_hhincloss_main)

//Hunger (missing num days goes missing)
recode w7_fdcyn w7_fdcskp w7_fdayn w7_fdaskp (-9/-1=.)
recode  w7_fdcyn w7_fdayn (2=0)

g w7_fdcyn_imp= w7_fdcyn
replace w7_fdcyn_imp= w7_fdcskp/5 if w7_fdcyn_imp==1

g w7_fdayn_imp= w7_fdayn 
replace w7_fdayn_imp= w7_fdaskp/5 if w7_fdayn_imp==1 & w7_fdaskp>0



*******************************************************************
*** New vars: Industry
* for the economically active population, has as good coverage as w7_occu
*******************************************************************


foreach var in w7_emsect_c w7_emssect w7_unemsect_c {
	replace `var' = . if `var' < 0
	replace `var' = . if `var' == 11 | `var' == 10
	assert inrange(`var', 0,9) | mi(`var')
}

gen w7_sect = w7_emsect_c
replace w7_sect = w7_emssect if mi(w7_sect)
replace w7_sect = w7_unemsect_c if mi(w7_sect)
label values w7_sect w2_nc_sec_code


*******************************************************************************
//Cleaned HH income var
// 1. Income lower bound
*===============================================================================



*cleaning tot grants per hh - reducing number of grants where total number of grants exceeds total number of eligible recipients in hh
// Note: This is not necessarily a correction which reduces noise: People are just as likely to misreport the number of elderly/children as they are to misreport the number of CSGs/OAPs
*csg
count if w7_csg_number > w7_tot_child
gen w7_csg_number_clean = w7_csg_number
replace w7_csg_number_clean = w7_tot_child if w7_csg_number > w7_tot_child & w7_csg_number !=.	// 314 replacements, wow

*oap
count if w7_oap_number > w7_tot_elder 
gen w7_oap_number_clean = w7_oap_number
replace w7_oap_number_clean = w7_tot_elder if w7_oap_number > w7_tot_elder & w7_oap_number !=.	// 14 changes

*lower bounds for income = grants in the household + reported labour earnings + personal grant receipt
* JB2 change to put 350* number of HH SRDs
// First, create these income items
gen w7_csg_inc = w7_csg_number*440+500
gen w7_oap_inc = w7_oap_number*2110
gen w7_csg_inc_cl = w7_csg_number_clean*440+500
gen w7_oap_inc_cl = w7_oap_number_clean*2110
gen w7_dg_inc = 2110 if w7_ind_incdis == 1
gen w7_fcg_inc = 1330 if w7_ind_incfos == 1
gen w7_cdg_inc = 2110 if w7_ind_inccare == 1
//gen w7_srdg_inc = 350 if w7_ind_inccovid ==1 
gen w7_srdg_inc = 350*w7_srd_number

// Second, sum these into a hh_inc lower bound (JB2 change added in SRDs which were not included before - not sure why?)
*Original hh level csg and oap vars
egen w7_hhincome_lb =     rsum(w7_csg_inc    w7_oap_inc    w7_dg_inc w7_fcg_inc w7_cdg_inc w7_srdg_inc  w7_totwage_jun), missing

*Cleaned hh level csg and oap vars
egen w7_hhincome_lb_cl =  rsum(w7_csg_inc_cl w7_oap_inc_cl w7_dg_inc w7_fcg_inc w7_cdg_inc  w7_srdg_inc w7_totwage_jun), missing

*3,200 higher incorrect (75%). Yikes!!
*count if w7_hhincome_lb>w7_hhincome_imp & w7_hhincome_lb!=. & w7_hhincome_imp!=.
*count if w7_hhincome_lb_cl>w7_hhincome_imp & w7_hhincome_lb_cl!=. & w7_hhincome_imp!=.

	
// 2. Outlier detection 
*===============================================================================
	
	// RZ: Using bacon (https://journals.sagepub.com/doi/pdf/10.1177/1536867X1001000302) to detect outliers in multivariate data, what I do here is predict an income/earnings value based on simple OLS, and then use bacon to determine whether observed values should be considered outliers, given the fitted value for income/earnings. The key parameter we as researchers need to determine, somewhat arbitrarily, is the "percentile" value. This is "the 1 − # percentile of the chi-squared distribution to be used as a threshold to separate outliers from nonoutliers" where a "larger # identifies a larger proportion of the sample as outliers.". Note that the p# I select is different for income than for earnings, which I determined after looking at the scatter plots which identify outliers. We can change this depending on what seems reasonable. 
	// Note: Still need to decide what to do about these outliers - probably the simplest and most sensible approach is to simply trim them. 

	gen w7_hhincome_ln = log(w7_hhincome_imp)
	gen w7_hhincome_noimp_ln = log(w7_hhincome)
	gen w7_hhincome_lb_ln = log(w7_hhincome_lb)
	gen w7_eminc_jun_imp_ln = log(w7_eminc_jun_imp)	
	
* JB2: WITH IMP (brackets)
******************

//RJ: removed repeats, w7_hhincome_lb, w7_hhsizer and included interactions 
	cap drop w7_hhincome_hat
	reg w7_hhincome_ln w7_age w7_hhsizer i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov [aw=fwgt], r 
	predict w7_hhincome_hat	

	cap drop out_hhinc
	bacon w7_hhincome_ln w7_hhincome_hat, generate(out_hhinc) percentile(0.15) replace
	*scatter w7_hhincome_ln w7_hhincome_hat, ml(out_hhinc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_hhincome_ln  if out_hhinc ==0 [aw=fwgt] ) (kdensity w7_hhincome_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//makes quite a bit of difference in density 

	* JB2 there was a mistake here, fixed	
	gen w7_hhincome_cl = w7_hhincome_imp if w7_outcome==1
	replace w7_hhincome_cl = . if out_hhinc ==1 & w7_outcome==1 // 65 outliers 
	
	
* JB2: WITHOUT IMP (brackets)
******************

//RJ: removed repeats, w7_hhincome_lb, w7_hhsizer and included interactions 
	cap drop w7_hhincome_noimp_hat
	reg w7_hhincome_noimp_ln w7_age w7_hhsizer i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov [aw=fwgt], r 
	predict w7_hhincome_noimp_hat	

	cap drop out_hhinc_noimp
	bacon w7_hhincome_noimp_ln w7_hhincome_noimp_hat, generate(out_hhinc_noimp) percentile(0.15) replace
	*scatter w7_hhincome_noimp_ln w7_hhincome_noimp_hat, ml(out_hhinc_noimp) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_hhincome_noimp_ln  if out_hhinc_noimp ==0 [aw=fwgt] ) (kdensity w7_hhincome_noimp_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//makes quite a bit of difference in density 

	gen w7_hhincome_noimp_cl = w7_hhincome if w7_outcome==1
	replace w7_hhincome_noimp_cl = . if out_hhinc_noimp ==1 & w7_outcome==1 // 51 outliers 

	
***	Earnings	
	cap drop w7_eminc_jun_imp_hat
	reg w7_eminc_jun_imp_ln w7_age i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov if w7_empl_stat ==3 [aw=fwgt], r
	predict w7_eminc_jun_imp_hat	

	cap drop out_eminc
	bacon w7_eminc_jun_imp_ln w7_eminc_jun_imp_hat, generate(out_eminc) percentile(0.15) replace 
	*scatter w7_eminc_jun_imp_ln w7_eminc_jun_imp_hat if w7_empl_stat ==3 , ml(out_eminc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_eminc_jun_imp_ln  if out_eminc ==0 [aw=fwgt] ) (kdensity w7_eminc_jun_imp_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//doesn't make much difference
		// JB2: still no difference here so justified to keep ignoring


* The income variables we're interested in
*===============================================================================		

lab var w7_hhincome "raw"
lab var w7_hhincome_imp "raw + brackets"
lab var w7_hhincome_lb "raw + brackets + lb"
lab var w7_hhincome_lb_cl "raw + brackets + clean lb"
lab var w7_hhincome_noimp_cl "raw + no outliers"
lab var w7_hhincome_cl "raw + brackets + no outliers"
	
	
/* RJ: not cleaned - not sure whether we'll need this/do this	
// 3. Various cleaned income variables
*===============================================================================
***	Main respondent from NIDS
	gen temp = w5_h_respondent if w6_outcome ==1
	gen w6_NIDShhrespondent = 0
	replace w6_NIDShhrespondent = 1 if temp ==pid
	drop temp

	tab w6_NIDShhrespondent [aw=w6_wgt], sum(w6_hhincome)
	
***	Income raw
	gen w6_hhincome_raw = w6_hhincome if w6_outcome==1
	
***	Income w/o outliers
	gen w6_hhincome_cl = w6_hhincome if w6_outcome==1
	replace w6_hhincome_cl = . if out_hhinc ==1 & w6_outcome==1 //13 outliers 
	
***	Income w/ LB imputation
	// NOTE: On line 34 above, I adjust no. of grants used in the LB estimate downward, based on reported number of grant eligible hh members. Need to decide whether to use the hh grants as given or use this adjusted variable
	gen w6_hhincome_imp = w6_hhincome_cl if w6_outcome==1
	replace w6_hhincome_imp = w6_hhincome_lb if w6_hhincome_lb > w6_hhincome_cl & w6_hhincome_lb !=. & w6_outcome==1 //1836 replaced out of 4395
	//replace w6_hhincome_imp = w6_hhincome_lb if w6_hhincome_cl==. & w6_hhincome_lb !=.   //RJ: if want to impose LB for missings too - but doesn't do a good job at all ->gen too many humps

/*
***RJ: Predicting who is replaced with LB:
	gen replaceLB=0 if w6_outcome==1 & w6_hhincome_cl!=.
	replace replaceLB=1 if w6_hhincome_lb > w6_hhincome_cl & w6_hhincome_lb !=. & w6_outcome==1
	reg replaceLB w6_age w6_hhsizer i.w6_race i.w6_area i.w6_educ_bins i.w6_gender i.w6_prov, r
	probit replaceLB w6_age w6_hhsizer i.w6_race i.w6_area i.w6_occu i.w6_educ_bins i.w6_gender i.w6_prov, r
	*/

***	Log of all our new hhincome vars + NIDS W5 vars
	foreach var in w6_hhincome_raw w6_hhincome_cl w6_hhincome_imp w5_hhq_inc w5_hhincome  {
	gen `var'_ln = log(`var')
	}


***RJ: checking the difference in bound and replaced value for those who are replaced
	*raw:
	gen dhhinc_imp_cl = w6_hhincome_imp - w6_hhincome_cl if replaceLB==1
	sum dhhinc_imp_cl, detail //
/*
	
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
dhhinc_imp~l |      1,836    2225.234    5277.656    1.21109   88065.74
*/
	*log scale:
	gen dhhinc_imp_cl_ln = w6_hhincome_imp_ln - w6_hhincome_cl_ln if replaceLB==1
	sum dhhinc_imp_cl_ln, detail

	
 Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
dhhinc_imp~n |      1,607    .5441973    .6319195   .0003223   4.238416

*/

	
*===============================================================================
***	END
*===============================================================================
